/**************************************************************************
    Souliss - Gateway
    
    For 10 nodes, network adressation 10.10.10.1.
    
    Node adress 10.10.10.102, 103 ....
    Gateway adress 10.10.1.101
    
    The maximum number of remote nodes from your gateway is by default 45
    
    Run this code on one of the following boards:
      - Arduino Ethernet (W5100) 
      - Arduino with Ethernet Shield (W5100)
      
    As option you can run the same code on the following, just changing the
    relevant configuration file at begin of the sketch
      - Arduino with W5200 Ethernet Shield
      - Arduino with W5500 Ethernet Shield
        
***************************************************************************/

// Configure the framework
#include "SoulissFramework.h"
#include "bconf/StandardArduino.h"          // Use a standard Arduino
#include "conf/ethW5100.h"                  // Ethernet through Wiznet W5100
#include "conf/Gateway.h"                   // The main node is the Gateway, we have just one node


// Include framework code and libraries
#include <SPI.h>
#include "Souliss.h"
#include <RCSwitch.h>


//Manual IP adress
uint8_t ip_address[4]  = {192, 168, 1, 230};
uint8_t subnet_mask[4] = {255, 255, 255, 0};
uint8_t ip_gateway[4]  = {192, 168, 1, 1};  

#define Gateway_address 230 //This is your gateway IP adress
#define Peer_address    231 //This is your peer adress nr 1
//#define Peer_address    103 //This is your peer adress nr 2

#define myvNet_address  ip_address[3]       // The last byte of the IP address (101) is also the vNet address
#define myvNet_subnet   0xFF00
#define myvNet_supern   Gateway_address
#define pTYP                    MaCaco_P_TYP_s
#define pOUT                    MaCaco_P_OUT_s
#define pTypical(node231,slot)     memory_map[pTYP+slot+(node*MaCaco_NODES*MaCaco_SLOT)]
#define pOutput(node231,slot)      memory_map[pOUT+slot+(node*MaCaco_NODES*MaCaco_SLOT)]
#define SHUTTER_NODE2 0
#define SHUTTER_NODE3 1

RCSwitch mySwitch = RCSwitch();


#define RcDigOut(code1, code2, value, slot) Souliss_RcDigOut(code1, code2, value, memory_map, slot)


// Send an output command to the wall socket 1
void Souliss_RcDigOut(U32 code1, U32 code2, U8 value, U8 *memory_map, U8 slot)
{
        // If output is active switch on the pin, else off
        if(memory_map[MaCaco_OUT_s + slot] == value)
                 mySwitch.send(code1, 24);
        else
                 mySwitch.send(code2, 24);
}


void setup()
{   
    Initialize();

 // Set network parameters
    Souliss_SetIPAddress(ip_address, subnet_mask, ip_gateway); //Setup adress
    SetAsGateway(myvNet_address);                             // Set this node as gateway for SoulissApp  

     // This node as gateway will get data from the Peer
    SetAsPeerNode(231, 1); //define peer node nr 1
    //SetAsPeerNode(Peer_address, 2); 
    //SetAsPeerNode(Peer_address, 3); 
        Set_T22(SHUTTER_NODE2);
        Set_T22(SHUTTER_NODE3);
        // Define inputs, outputs pins
        pinMode(7, OUTPUT);            // trasmettitore 433Mhz

        // Transmitter is connected to Arduino Pin #7 
        mySwitch.enableTransmit(7);

        //Serial.begin(9600); // for debug

}

void loop()
{   
    // Here we start to play
    EXECUTEFAST() {                     
        UPDATEFAST();
           // Read every 510ms the input state and send it to the other board  
        FAST_510ms() {
          
          
          // Control the Wall socket 1/2                      
                        Logic_T22(SHUTTER_NODE2);
                        Logic_T22(SHUTTER_NODE3);

                    
                        if(data_changed) {
                               RcDigOut(8573265, 24, Souliss_T2n_Coil_Open, SHUTTER_NODE2);    
                               RcDigOut(8573266, 24, Souliss_T2n_Coil_Close, SHUTTER_NODE2);
                               RcDigOut(5456581, 24, Souliss_T2n_Coil_Open, SHUTTER_NODE3);    
                               RcDigOut(5456582, 24, Souliss_T2n_Coil_Close, SHUTTER_NODE3);
                        }
 }
        }

        // Here we handle here the communication with Android, commands and notification
        FAST_GatewayComms();
}    


